.. _Milly-Rodriguez:

Milly Rodriguez
:::::::::::::::::::::::::::::::::::::

.. role:: raw-html(raw)
   :format: html

:raw-html:`<font color="CadetBlue"><em>"I didn't know that people go to school for [computing], didn't know that there was programs that could help build websites, didn't know there was books that I could read on computers. I didn't realize the possibility of a career until really after college was done."</em></font>`

.. image:: ../../../_static/Interviewees/M_Rodriguez.jpg
    :width: 350
    :align: right
    :alt: Picture of Milly

**How did she get into computing?**

*"I was just encouraged because I wanted to connect with other people online. So I was creating websites. I had my own blog, I was redesigning my website every month or so. I had hosting. And that was just a way to connect with other people that were also interested and also have their own website. There was nobody really that kind of pushed me to be in computers."*

**How did she pursue computing?**

Because she didn't know that computing was a viable career path, Milly didn't study it in college. Instead, she worked retail for a bit until she rediscovered her love for computing. She saved for a bit, quit her job, and went to a bootcamp. It was a gamble, but it paid off. She ended up with a solid education and a career shortly thereafter.

**Who does she look up to?**

*"I got some personal assistance from a person that kind of became a mentor that was already working in the field, so I was able to have some direct, constant contact with somebody that was doing the job. This was a black male, and he was a senior engineer at a really well-known company... This person kind of became my goal. This person was well established, was able to take care of his family, was able to reach your financial goals. And this is something that I saw myself doing."*


**What does she work as?**

Milly is an assistant software engineer at a telemedicine company. She mostly serves as a front-end developer, a role that designs the visible parts of a website (i.e., the components that users interact with). Specifically, a lot of her work deals with retooling sites to be more accessible for visually or hearing-impaired people.

.. youtube:: 1blqqSnIIFo
    :divid: Milly_Rodriguez
    :height: 315
    :width: 560